==> ejc-credentials-impl-3.0.0-20220518.110548-20-sources.jar: com/ejianc/certify/bean/CorpApplyHEntity.java <==
package com.ejianc.certify.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 证件借用申请-表头
 *
 * @author generator
 *
 */
@TableName("jzctm_corpcertifapply")
public class CorpApplyHEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="approver")
    private Long approver; // 审批人
    @TableField(value="taudittime")
    private String taudittime; // 审批时间
    @TableField(value="vapprovenote")
    private String vapprovenote; // 审批附言
    @TableField(value="fstatusflag")
    private Integer fstatusflag; // 单据状态
    @TableField(value="pk_billtype")
    private Long pkBilltype; // 单据类型
    @TableField(value="ts")
    private Date ts; // 时间戳
    @TableField(value="vbusitype")
    private String vbusitype; // 业务类型（1-项目报建 2-工程投标 3-区域备案）
    @TableField(value="pk_group")
    private String pkGroup; // 集团
    @TableField(value="pk_org")
    private Long pkOrg; // 发起人组织
    @TableField(value="pk_dept")
    private Long pkDept; // 发起人部门
    @TableField(value="vbillcode")
    private String vbillcode; // 单据编号
    @TableField(value="dbilldate")
    private String dbilldate; // 单据日期
    @TableField(value="vmemo")
    private String vmemo; // 备注
    @TableField(value="pk_fqr")
    private Long pkFqr; // 发起人
    @TableField(value="applyer_tel")
    private String applyerTel; // 发起人电话
    @TableField(value="applydate")
    private String applydate; // 申请时间
    @TableField(value="applyreason")
    private String applyreason; // 用途
    @TableField(value="pk_project")
    private Long pkProject; // 报建立项
    @TableField(value="pk_contract")
    private Long pkContract; // 报建合同
    @TableField(value="pk_pmproject")
    private Long pkPmproject; // 施工项目立项
    @TableField(value="pk_pmproject_jlb")
    private Long pkPmprojectJlb; // 项目经理部
    @TableField(value="project_finish_time")
    private String projectFinishTime; // 项目预计竣工时间
    @TableField(value="vdef1")
    private String vdef1; //
    @TableField(value="vdef10")
    private String vdef10; //
    @TableField(value="vdef2")
    private String vdef2; //
    @TableField(value="vdef3")
    private String vdef3; //
    @TableField(value="vdef4")
    private String vdef4; //
    @TableField(value="vdef5")
    private String vdef5; //
    @TableField(value="vdef6")
    private String vdef6; //
    @TableField(value="vdef7")
    private String vdef7; //
    @TableField(value="vdef8")
    private String vdef8; //
    @TableField(value="vdef9")
    private String vdef9; //

    @TableField(exist = false)
    @SubEntity(serviceName = "corpApplyBService", pidName = "pkCorpcertifapply")
    private List<CorpApplyBEntity> corpApplyBList = new ArrayList<>();

    public List<CorpApplyBEntity> getCorpApplyBList() {
        return corpApplyBList;
    }

    public void setCorpApplyBList(List<CorpApplyBEntity> corpApplyBList) {
        this.corpApplyBList = corpApplyBList;
    }


    public Long getApprover() {
        return approver;
    }

    public void setApprover(Long approver) {
        this.approver = approver;
    }
    public String getTaudittime() {
        return taudittime;
    }

    public void setTaudittime(String taudittime) {
        this.taudittime = taudittime;
    }
    public String getVapprovenote() {
        return vapprovenote;
    }

    public void setVapprovenote(String vapprovenote) {
        this.vapprovenote = vapprovenote;
    }
    public Integer getFstatusflag() {
        return fstatusflag;
    }

    public void setFstatusflag(Integer fstatusflag) {
        this.fstatusflag = fstatusflag;
    }
    public Long getPkBilltype() {
        return pkBilltype;
    }

    public void setPkBilltype(Long pkBilltype) {
        this.pkBilltype = pkBilltype;
    }
    public Date getTs() {
        return ts;
    }

    public void setTs(Date ts) {
        this.ts = ts;
    }
    public String getVbusitype() {
        return vbusitype;
    }

    public void setVbusitype(String vbusitype) {
        this.vbusitype = vbusitype;
    }
    public String getPkGroup() {
        return pkGroup;
    }

    public void setPkGroup(String pkGroup) {
        this.pkGroup = pkGroup;
    }
    public Long getPkOrg() {
        return pkOrg;
    }

    public void setPkOrg(Long pkOrg) {
        this.pkOrg = pkOrg;
    }
    public Long getPkDept() {
        return pkDept;
    }

    public void setPkDept(Long pkDept) {
        this.pkDept = pkDept;
    }
    public String getVbillcode() {
        return vbillcode;
    }

    public void setVbillcode(String vbillcode) {
        this.vbillcode = vbillcode;
    }
    public String getDbilldate() {
        return dbilldate;
    }

    public void setDbilldate(String dbilldate) {
        this.dbilldate = dbilldate;
    }
    public String getVmemo() {
        return vmemo;
    }

    public void setVmemo(String vmemo) {
        this.vmemo = vmemo;
    }
    public Long getPkFqr() {
        return pkFqr;
    }

    public void setPkFqr(Long pkFqr) {
        this.pkFqr = pkFqr;
    }
    public String getApplyerTel() {
        return applyerTel;
    }

    public void setApplyerTel(String applyerTel) {
        this.applyerTel = applyerTel;
    }
    public String getApplydate() {
        return applydate;
    }

    public void setApplydate(String applydate) {
        this.applydate = applydate;
    }
    public String getApplyreason() {
        return applyreason;
    }

    public void setApplyreason(String applyreason) {
        this.applyreason = applyreason;
    }
    public Long getPkProject() {
        return pkProject;
    }

    public void setPkProject(Long pkProject) {
        this.pkProject = pkProject;
    }
    public Long getPkContract() {
        return pkContract;
    }

    public void setPkContract(Long pkContract) {
        this.pkContract = pkContract;
    }
    public Long getPkPmproject() {
        return pkPmproject;
    }

    public void setPkPmproject(Long pkPmproject) {
        this.pkPmproject = pkPmproject;
    }
    public Long getPkPmprojectJlb() {
        return pkPmprojectJlb;
    }

    public void setPkPmprojectJlb(Long pkPmprojectJlb) {
        this.pkPmprojectJlb = pkPmprojectJlb;
    }
    public String getProjectFinishTime() {
        return projectFinishTime;
    }

    public void setProjectFinishTime(String projectFinishTime) {
        this.projectFinishTime = projectFinishTime;
    }
    public String getVdef1() {
        return vdef1;
    }

    public void setVdef1(String vdef1) {
        this.vdef1 = vdef1;
    }
    public String getVdef10() {
        return vdef10;
    }

    public void setVdef10(String vdef10) {
        this.vdef10 = vdef10;
    }
    public String getVdef2() {
        return vdef2;
    }

    public void setVdef2(String vdef2) {
        this.vdef2 = vdef2;
    }
    public String getVdef3() {
        return vdef3;
    }

    public void setVdef3(String vdef3) {
        this.vdef3 = vdef3;
    }
    public String getVdef4() {
        return vdef4;
    }

    public void setVdef4(String vdef4) {
        this.vdef4 = vdef4;
    }
    public String getVdef5() {
        return vdef5;
    }

    public void setVdef5(String vdef5) {
        this.vdef5 = vdef5;
    }
    public String getVdef6() {
        return vdef6;
    }

    public void setVdef6(String vdef6) {
        this.vdef6 = vdef6;
    }
    public String getVdef7() {
        return vdef7;
    }

    public void setVdef7(String vdef7) {
        this.vdef7 = vdef7;
    }
    public String getVdef8() {
        return vdef8;
    }

    public void setVdef8(String vdef8) {
        this.vdef8 = vdef8;
    }
    public String getVdef9() {
        return vdef9;
    }

    public void setVdef9(String vdef9) {
        this.vdef9 = vdef9;
    }

}

==> ejc-credentials-impl-3.0.0-20220609.021040-45-sources.jar: com/ejianc/certify/bean/CorpApplyHEntity.java <==
package com.ejianc.certify.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 证件借用申请-表头
 *
 * @author generator
 *
 */
@TableName("jzctm_corpcertifapply")
public class CorpApplyHEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="approver")
    private Long approver; // 审批人
    @TableField(value="taudittime")
    private String taudittime; // 审批时间
    @TableField(value="vapprovenote")
    private String vapprovenote; // 审批附言
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="pk_billtype")
    private Long pkBilltype; // 单据类型
    @TableField(value="ts")
    private Date ts; // 时间戳
    @TableField(value="vbusitype")
    private String vbusitype; // 业务类型（1-项目报建 2-工程投标 3-区域备案）
    @TableField(value="pk_group")
    private String pkGroup; // 集团
    @TableField(value="pk_org")
    private Long pkOrg; // 发起人组织
    @TableField(value="pk_dept")
    private Long pkDept; // 发起人部门
    @TableField(value="vbillcode")
    private String vbillcode; // 单据编号
    @TableField(value="dbilldate")
    private String dbilldate; // 单据日期
    @TableField(value="vmemo")
    private String vmemo; // 备注
    @TableField(value="pk_fqr")
    private Long pkFqr; // 发起人
    @TableField(value="applyer_tel")
    private String applyerTel; // 发起人电话
    @TableField(value="applydate")
    private String applydate; // 申请时间
    @TableField(value="applyreason")
    private String applyreason; // 用途
    @TableField(value="pk_project")
    private Long pkProject; // 报建立项
    @TableField(value="pk_contract")
    private Long pkContract; // 报建合同
    @TableField(value="pk_pmproject")
    private Long pkPmproject; // 施工项目立项
    @TableField(value="pk_pmproject_jlb")
    private Long pkPmprojectJlb; // 项目经理部
    @TableField(value="project_finish_time")
    private String projectFinishTime; // 项目预计竣工时间
    @TableField(value="vdef1")
    private String vdef1; //
    @TableField(value="vdef10")
    private String vdef10; //
    @TableField(value="vdef2")
    private String vdef2; //
    @TableField(value="vdef3")
    private String vdef3; //
    @TableField(value="vdef4")
    private String vdef4; //
    @TableField(value="vdef5")
    private String vdef5; //
    @TableField(value="vdef6")
    private String vdef6; //
    @TableField(value="vdef7")
    private String vdef7; //
    @TableField(value="vdef8")
    private String vdef8; //
    @TableField(value="vdef9")
    private String vdef9; //

    @TableField(exist = false)
    @SubEntity(serviceName = "corpApplyBService", pidName = "pkCorpcertifapply")
    private List<CorpApplyBEntity> corpApplyBList = new ArrayList<>();

    public List<CorpApplyBEntity> getCorpApplyBList() {
        return corpApplyBList;
    }

    public void setCorpApplyBList(List<CorpApplyBEntity> corpApplyBList) {
        this.corpApplyBList = corpApplyBList;
    }


    public Long getApprover() {
        return approver;
    }

    public void setApprover(Long approver) {
        this.approver = approver;
    }
    public String getTaudittime() {
        return taudittime;
    }

    public void setTaudittime(String taudittime) {
        this.taudittime = taudittime;
    }
    public String getVapprovenote() {
        return vapprovenote;
    }

    public void setVapprovenote(String vapprovenote) {
        this.vapprovenote = vapprovenote;
    }

    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

    public Long getPkBilltype() {
        return pkBilltype;
    }

    public void setPkBilltype(Long pkBilltype) {
        this.pkBilltype = pkBilltype;
    }
    public Date getTs() {
        return ts;
    }

    public void setTs(Date ts) {
        this.ts = ts;
    }
    public String getVbusitype() {
        return vbusitype;
    }

    public void setVbusitype(String vbusitype) {
        this.vbusitype = vbusitype;
    }
    public String getPkGroup() {
        return pkGroup;
    }

    public void setPkGroup(String pkGroup) {
        this.pkGroup = pkGroup;
    }
    public Long getPkOrg() {
        return pkOrg;
    }

    public void setPkOrg(Long pkOrg) {
        this.pkOrg = pkOrg;
    }
    public Long getPkDept() {
        return pkDept;
    }

    public void setPkDept(Long pkDept) {
        this.pkDept = pkDept;
    }
    public String getVbillcode() {
        return vbillcode;
    }

    public void setVbillcode(String vbillcode) {
        this.vbillcode = vbillcode;
    }
    public String getDbilldate() {
        return dbilldate;
    }

    public void setDbilldate(String dbilldate) {
        this.dbilldate = dbilldate;
    }
    public String getVmemo() {
        return vmemo;
    }

    public void setVmemo(String vmemo) {
        this.vmemo = vmemo;
    }
    public Long getPkFqr() {
        return pkFqr;
    }

    public void setPkFqr(Long pkFqr) {
        this.pkFqr = pkFqr;
    }
    public String getApplyerTel() {
        return applyerTel;
    }

    public void setApplyerTel(String applyerTel) {
        this.applyerTel = applyerTel;
    }
    public String getApplydate() {
        return applydate;
    }

    public void setApplydate(String applydate) {
        this.applydate = applydate;
    }
    public String getApplyreason() {
        return applyreason;
    }

    public void setApplyreason(String applyreason) {
        this.applyreason = applyreason;
    }
    public Long getPkProject() {
        return pkProject;
    }

    public void setPkProject(Long pkProject) {
        this.pkProject = pkProject;
    }
    public Long getPkContract() {
        return pkContract;
    }

    public void setPkContract(Long pkContract) {
        this.pkContract = pkContract;
    }
    public Long getPkPmproject() {
        return pkPmproject;
    }

    public void setPkPmproject(Long pkPmproject) {
        this.pkPmproject = pkPmproject;
    }
    public Long getPkPmprojectJlb() {
        return pkPmprojectJlb;
    }

    public void setPkPmprojectJlb(Long pkPmprojectJlb) {
        this.pkPmprojectJlb = pkPmprojectJlb;
    }
    public String getProjectFinishTime() {
        return projectFinishTime;
    }

    public void setProjectFinishTime(String projectFinishTime) {
        this.projectFinishTime = projectFinishTime;
    }
    public String getVdef1() {
        return vdef1;
    }

    public void setVdef1(String vdef1) {
        this.vdef1 = vdef1;
    }
    public String getVdef10() {
        return vdef10;
    }

    public void setVdef10(String vdef10) {
        this.vdef10 = vdef10;
    }
    public String getVdef2() {
        return vdef2;
    }

    public void setVdef2(String vdef2) {
        this.vdef2 = vdef2;
    }
    public String getVdef3() {
        return vdef3;
    }

    public void setVdef3(String vdef3) {
        this.vdef3 = vdef3;
    }
    public String getVdef4() {
        return vdef4;
    }

    public void setVdef4(String vdef4) {
        this.vdef4 = vdef4;
    }
    public String getVdef5() {
        return vdef5;
    }

    public void setVdef5(String vdef5) {
        this.vdef5 = vdef5;
    }
    public String getVdef6() {
        return vdef6;
    }

    public void setVdef6(String vdef6) {
        this.vdef6 = vdef6;
    }
    public String getVdef7() {
        return vdef7;
    }

    public void setVdef7(String vdef7) {
        this.vdef7 = vdef7;
    }
    public String getVdef8() {
        return vdef8;
    }

    public void setVdef8(String vdef8) {
        this.vdef8 = vdef8;
    }
    public String getVdef9() {
        return vdef9;
    }

    public void setVdef9(String vdef9) {
        this.vdef9 = vdef9;
    }

}
